/*_############################################################################
  _## 
  _##  SNMP4J-Model - DefaultSnmpProxyRegistry.java  
  _## 
  _##  Copyright (C) 2013-2022  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.model.snmp.api;

import org.snmp4j.model.snmp.proxy.SnmpProxyObject;
import org.snmp4j.model.snmp.spi.SnmpProxyRegistry;
import org.snmp4j.smi.OctetString;

import java.util.*;

/**
 * The {@link DefaultSnmpProxyRegistry} provides a default registry for Snmp
 */
public class DefaultSnmpProxyRegistry implements SnmpProxyRegistry {

  private SortedMap<SnmpProxyId, SnmpProxyObject> registry =
      Collections.synchronizedSortedMap(new TreeMap<SnmpProxyId, SnmpProxyObject>());

  public DefaultSnmpProxyRegistry() {
  }

  @Override
  public SnmpProxyObject getProxy(SnmpProxyId snmpProxyId) {
    return registry.get(snmpProxyId);
  }

  @Override
  public SnmpProxyObject putProxy(SnmpProxyId snmpProxyId, SnmpProxyObject snmpProxyObject) {
     return registry.put(snmpProxyId, snmpProxyObject);
  }

  @Override
  public SnmpProxyObject removeProxy(SnmpProxyId snmpProxyId) {
    return registry.remove(snmpProxyId);
  }

  @Override
  public SortedMap<SnmpProxyId, SnmpProxyObject> getProxyMap() {
    return registry;
  }

}
